@@ -96,7 +96,7 @@ def job(experiment_path, rule_height_factor):
     # Rule Population Clustermaps
     r = seaborn.clustermap(rule_df, metric='sqeuclidean', method='ward', cmap=cmap, cbar_kws={'ticks':[0,1]})
 
-    feature_order_indices = r.dendrogram_row.reordered_ind
+    feature_order_indices = r.dendrogram_col.reordered_ind
     new_feature_order = []
     for i in feature_order_indices:
         new_feature_order.append(data_headers[i])
